@@ -170,6 +170,11 @@ impl From<Block> for FirehoseBlock {
     }
 }
 
-uint::construct_uint! {
-    pub struct U256(4);
+#[allow(clippy::all)]
+mod uints {
+    uint::construct_uint! {
+        pub struct U256(4);
+    }
 }
+
+pub use uints::U256;
